package com.fuyuanshen.app.service;

import com.fuyuanshen.app.domain.vo.AppRoleVo;
import com.fuyuanshen.app.domain.bo.AppRoleBo;
import com.fuyuanshen.common.mybatis.core.page.TableDataInfo;
import com.fuyuanshen.common.mybatis.core.page.PageQuery;

import java.util.Collection;
import java.util.List;
import java.util.Set;

/**
 * 角色信息Service接口
 *
 * @author Lion Li
 * @date 2025-06-27
 */
public interface IAppRoleService {

    /**
     * 查询角色信息
     *
     * @param roleId 主键
     * @return 角色信息
     */
    AppRoleVo queryById(Long roleId);

    /**
     * 分页查询角色信息列表
     *
     * @param bo        查询条件
     * @param pageQuery 分页参数
     * @return 角色信息分页列表
     */
    TableDataInfo<AppRoleVo> queryPageList(AppRoleBo bo, PageQuery pageQuery);

    /**
     * 查询符合条件的角色信息列表
     *
     * @param bo 查询条件
     * @return 角色信息列表
     */
    List<AppRoleVo> queryList(AppRoleBo bo);

    /**
     * 新增角色信息
     *
     * @param bo 角色信息
     * @return 是否新增成功
     */
    Boolean insertByBo(AppRoleBo bo);

    /**
     * 修改角色信息
     *
     * @param bo 角色信息
     * @return 是否修改成功
     */
    Boolean updateByBo(AppRoleBo bo);

    /**
     * 校验并批量删除角色信息信息
     *
     * @param ids     待删除的主键集合
     * @param isValid 是否进行有效性校验
     * @return 是否删除成功
     */
    Boolean deleteWithValidByIds(Collection<Long> ids, Boolean isValid);

    Set<String> selectRolePermissionByUserId(Long userId);

    /**
     * 根据用户ID查询角色列表
     *
     * @param userId 用户ID
     * @return 角色列表
     */
    List<AppRoleVo> selectRolesByUserId(Long userId);
}
